//  Copyright (c) 2020 ETH Zurich
//
//  SPDX-License-Identifier: BSL-1.0
//  Distributed under the Boost Software License, Version 1.0. (See accompanying
//  file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)

#pragma once

#include <hpx/config.hpp>
#include <hpx/parallel/algorithm.hpp>
#include <hpx/parallel/container_algorithms.hpp>
#include <hpx/parallel/unseq.hpp>
#if defined(HPX_HAVE_DATAPAR)
#include <hpx/parallel/datapar.hpp>
#endif
#include <hpx/parallel/segmented_algorithm.hpp>
